// Netify Agent Log Sink Plugin
// Copyright (C) 2021-2023 eGloo Incorporated
// <http://www.egloo.ca>

#ifndef _NSP_PLUGIN_H
#define _NSP_PLUGIN_H

#include <nd-plugin.hpp>

#define _NSP_DEFAULT_LOG_PATH "/tmp"

class nspChannelConfig {
 public:
  nspChannelConfig()
      : log_path(_NSP_DEFAULT_LOG_PATH), overwrite(false) {}

  void Load(const string &channel, const json &jconf);
  inline void Load(const string &channel, const json &jconf,
                   nspChannelConfig &defaults) {
    log_path = defaults.log_path;
    overwrite = defaults.overwrite;
    Load(channel, jconf);
  }

  string channel;
  string log_path;
  string log_name;
  bool overwrite;
};

class nspPlugin : public ndPluginSink {
 public:
  nspPlugin(const string &tag,
            const ndPlugin::Params &params);
  virtual ~nspPlugin();

  virtual void *Entry(void);

  virtual void DispatchEvent(ndPlugin::Event event,
                             void *param = nullptr);

  virtual void GetVersion(string &version) {
    version = PACKAGE_VERSION;
  }

 protected:
  atomic<bool> reload;

  nspChannelConfig defaults;
  map<string, nspChannelConfig> channels;

  void Reload(void);
  void WritePayload(ndPluginSinkPayload *payload);
};

#endif  // _NSP_PLUGIN_H
